[polly] r314519 - [ScopBuilder] Fix typo. NFC.

Michael Kruse via llvm-commits llvm-commits at lists.llvm.org
Fri Sep 29 08:13:06 PDT 2017


Author: meinersbur
Date: Fri Sep 29 08:13:05 2017
New Revision: 314519

URL: http://llvm.org/viewvc/llvm-project?rev=314519&view=rev
Log:
[ScopBuilder] Fix typo. NFC.

Contributed-by: Nandini Singhal <cs15mtech01004 at iith.ac.in>

Differential Revision: https://reviews.llvm.org/D38322

Modified:
    polly/trunk/include/polly/ScopBuilder.h
    polly/trunk/lib/Analysis/ScopBuilder.cpp

Modified: polly/trunk/include/polly/ScopBuilder.h
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/include/polly/ScopBuilder.h?rev=314519&r1=314518&r2=314519&view=diff
==============================================================================
--- polly/trunk/lib/Analysis/ScopBuilder.cpp (original)
+++ polly/trunk/lib/Analysis/ScopBuilder.cpp Fri Sep 29 08:13:05 2017
@@ -984,7 +984,7 @@ void ScopBuilder::checkForReductions(Sco
       continue;
 
     Loads.clear();
-    collectCandiateReductionLoads(StoreMA, Loads);
+    collectCandidateReductionLoads(StoreMA, Loads);
     for (MemoryAccess *LoadMA : Loads)
       Candidates.push_back(std::make_pair(LoadMA, StoreMA));
   }
@@ -1034,7 +1034,7 @@ void ScopBuilder::checkForReductions(Sco
   }
 }
 
-void ScopBuilder::collectCandiateReductionLoads(
+void ScopBuilder::collectCandidateReductionLoads(
     MemoryAccess *StoreMA, SmallVectorImpl<MemoryAccess *> &Loads) {
   ScopStmt *Stmt = StoreMA->getStatement();
 




More information about the llvm-commits mailing list
--- polly/trunk/include/polly/ScopBuilder.h (original)
+++ polly/trunk/include/polly/ScopBuilder.h Fri Sep 29 08:13:05 2017
@@ -356,7 +356,7 @@ class ScopBuilder {
   /// base address and there are no other accesses which overlap with them. The
   /// base address check rules out impossible reductions candidates early. The
   /// overlap check, together with the "only one user" check in
   /// collectCandiateReductionLoads, guarantees that none of the intermediate
   /// results will escape during execution of the loop nest. We basically check
   /// here that no other memory access can access the same memory as the
   /// potential reduction.
@@ -372,8 +372,8 @@ class ScopBuilder {
   ///
   /// Note: We allow only one use to ensure the load and binary operator cannot
   ///       escape this block or into any other store except @p StoreMA.
-  void collectCandiateReductionLoads(MemoryAccess *StoreMA,
-                                     SmallVectorImpl<MemoryAccess *> &Loads);
+  void collectCandidateReductionLoads(MemoryAccess *StoreMA,
+                                      SmallVectorImpl<MemoryAccess *> &Loads);
 
   /// Build the access relation of all memory accesses of @p Stmt.
   void buildAccessRelations(ScopStmt &Stmt);
@@ -356,7 +356,7 @@ class ScopBuilder {
   /// base address check rules out impossible reductions candidates early. The
   /// overlap check, together with the "only one user" check in
-  /// collectCandiateReductionLoads, guarantees that none of the intermediate
+  /// collectCandidateReductionLoads, guarantees that none of the intermediate
   /// results will escape during execution of the loop nest. We basically check
   /// here that no other memory access can access the same memory as the

Modified: polly/trunk/lib/Analysis/ScopBuilder.cpp
URL: http://llvm.org/viewvc/llvm-project/polly/trunk/lib/Analysis/ScopBuilder.cpp?rev=314519&r1=314518&r2=314519&view=diff
==============================================================================